/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/amp/PrometheusService_EXPORTS.h>
#include <aws/amp/model/AnomalyDetectorSummary.h>
#include <aws/core/http/HttpResponse.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>

#include <utility>

namespace Aws {
template <typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils {
namespace Json {
class JsonValue;
}  // namespace Json
}  // namespace Utils
namespace PrometheusService {
namespace Model {
class ListAnomalyDetectorsResult {
 public:
  AWS_PROMETHEUSSERVICE_API ListAnomalyDetectorsResult() = default;
  AWS_PROMETHEUSSERVICE_API ListAnomalyDetectorsResult(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
  AWS_PROMETHEUSSERVICE_API ListAnomalyDetectorsResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);

  ///@{
  /**
   * <p>The list of anomaly detectors in the workspace.</p>
   */
  inline const Aws::Vector<AnomalyDetectorSummary>& GetAnomalyDetectors() const { return m_anomalyDetectors; }
  template <typename AnomalyDetectorsT = Aws::Vector<AnomalyDetectorSummary>>
  void SetAnomalyDetectors(AnomalyDetectorsT&& value) {
    m_anomalyDetectorsHasBeenSet = true;
    m_anomalyDetectors = std::forward<AnomalyDetectorsT>(value);
  }
  template <typename AnomalyDetectorsT = Aws::Vector<AnomalyDetectorSummary>>
  ListAnomalyDetectorsResult& WithAnomalyDetectors(AnomalyDetectorsT&& value) {
    SetAnomalyDetectors(std::forward<AnomalyDetectorsT>(value));
    return *this;
  }
  template <typename AnomalyDetectorsT = AnomalyDetectorSummary>
  ListAnomalyDetectorsResult& AddAnomalyDetectors(AnomalyDetectorsT&& value) {
    m_anomalyDetectorsHasBeenSet = true;
    m_anomalyDetectors.emplace_back(std::forward<AnomalyDetectorsT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The pagination token to retrieve the next set of results.</p>
   */
  inline const Aws::String& GetNextToken() const { return m_nextToken; }
  template <typename NextTokenT = Aws::String>
  void SetNextToken(NextTokenT&& value) {
    m_nextTokenHasBeenSet = true;
    m_nextToken = std::forward<NextTokenT>(value);
  }
  template <typename NextTokenT = Aws::String>
  ListAnomalyDetectorsResult& WithNextToken(NextTokenT&& value) {
    SetNextToken(std::forward<NextTokenT>(value));
    return *this;
  }
  ///@}

  ///@{

  inline const Aws::String& GetRequestId() const { return m_requestId; }
  template <typename RequestIdT = Aws::String>
  void SetRequestId(RequestIdT&& value) {
    m_requestIdHasBeenSet = true;
    m_requestId = std::forward<RequestIdT>(value);
  }
  template <typename RequestIdT = Aws::String>
  ListAnomalyDetectorsResult& WithRequestId(RequestIdT&& value) {
    SetRequestId(std::forward<RequestIdT>(value));
    return *this;
  }
  ///@}
  inline Aws::Http::HttpResponseCode GetHttpResponseCode() const { return m_HttpResponseCode; }

 private:
  Aws::Vector<AnomalyDetectorSummary> m_anomalyDetectors;

  Aws::String m_nextToken;

  Aws::String m_requestId;
  Aws::Http::HttpResponseCode m_HttpResponseCode;
  bool m_anomalyDetectorsHasBeenSet = false;
  bool m_nextTokenHasBeenSet = false;
  bool m_requestIdHasBeenSet = false;
};

}  // namespace Model
}  // namespace PrometheusService
}  // namespace Aws
