/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/client/GenericClientConfiguration.h>
#include <aws/core/endpoint/DefaultEndpointProvider.h>
#include <aws/core/endpoint/EndpointParameter.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/dataexchange/DataExchangeEndpointRules.h>
#include <aws/dataexchange/DataExchange_EXPORTS.h>

namespace Aws {
namespace DataExchange {
namespace Endpoint {
using EndpointParameters = Aws::Endpoint::EndpointParameters;
using Aws::Endpoint::DefaultEndpointProvider;
using Aws::Endpoint::EndpointProviderBase;

using DataExchangeClientContextParameters = Aws::Endpoint::ClientContextParameters;

using DataExchangeClientConfiguration = Aws::Client::GenericClientConfiguration;
using DataExchangeBuiltInParameters = Aws::Endpoint::BuiltInParameters;

/**
 * The type for the DataExchange Client Endpoint Provider.
 * Inherit from this Base class / "Interface" should you want to provide a custom endpoint provider.
 * The SDK must use service-specific type for each service per specification.
 */
using DataExchangeEndpointProviderBase =
    EndpointProviderBase<DataExchangeClientConfiguration, DataExchangeBuiltInParameters, DataExchangeClientContextParameters>;

using DataExchangeDefaultEpProviderBase =
    DefaultEndpointProvider<DataExchangeClientConfiguration, DataExchangeBuiltInParameters, DataExchangeClientContextParameters>;

/**
 * Default endpoint provider used for this service
 */
class AWS_DATAEXCHANGE_API DataExchangeEndpointProvider : public DataExchangeDefaultEpProviderBase {
 public:
  using DataExchangeResolveEndpointOutcome = Aws::Endpoint::ResolveEndpointOutcome;

  DataExchangeEndpointProvider()
      : DataExchangeDefaultEpProviderBase(Aws::DataExchange::DataExchangeEndpointRules::GetRulesBlob(),
                                          Aws::DataExchange::DataExchangeEndpointRules::RulesBlobSize) {}

  ~DataExchangeEndpointProvider() {}
};
}  // namespace Endpoint
}  // namespace DataExchange
}  // namespace Aws
